//[mahjong-utils](../../../index.md)/[mahjongutils.hora](../index.md)/[Hora](index.md)/[childPoint](child-point.md)

# childPoint

[common]\

@EncodeDefault

val [childPoint](child-point.md): [ChildPoint](../../mahjongutils.hanhu/-child-point/index.md)

子家（闲家）和牌点数
